# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.cloud import asset_v1p2beta1
from google.cloud.asset_v1p2beta1.proto import asset_service_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestAssetServiceClient(object):
    def test_delete_feed(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup Request
        name = "name3373707"

        client.delete_feed(name)

        assert len(channel.requests) == 1
        expected_request = asset_service_pb2.DeleteFeedRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_feed_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup request
        name = "name3373707"

        with pytest.raises(CustomException):
            client.delete_feed(name)

    def test_create_feed(self):
        # Setup Expected Response
        name = "name3373707"
        expected_response = {"name": name}
        expected_response = asset_service_pb2.Feed(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup Request
        parent = "parent-995424086"
        feed_id = "feedId-976011428"
        feed = {}

        response = client.create_feed(parent, feed_id, feed)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = asset_service_pb2.CreateFeedRequest(
            parent=parent, feed_id=feed_id, feed=feed
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_feed_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup request
        parent = "parent-995424086"
        feed_id = "feedId-976011428"
        feed = {}

        with pytest.raises(CustomException):
            client.create_feed(parent, feed_id, feed)

    def test_get_feed(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        expected_response = {"name": name_2}
        expected_response = asset_service_pb2.Feed(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup Request
        name = "name3373707"

        response = client.get_feed(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = asset_service_pb2.GetFeedRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_feed_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup request
        name = "name3373707"

        with pytest.raises(CustomException):
            client.get_feed(name)

    def test_list_feeds(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = asset_service_pb2.ListFeedsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup Request
        parent = "parent-995424086"

        response = client.list_feeds(parent)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = asset_service_pb2.ListFeedsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_feeds_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup request
        parent = "parent-995424086"

        with pytest.raises(CustomException):
            client.list_feeds(parent)

    def test_update_feed(self):
        # Setup Expected Response
        name = "name3373707"
        expected_response = {"name": name}
        expected_response = asset_service_pb2.Feed(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup Request
        feed = {}
        update_mask = {}

        response = client.update_feed(feed, update_mask)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = asset_service_pb2.UpdateFeedRequest(
            feed=feed, update_mask=update_mask
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_feed_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = asset_v1p2beta1.AssetServiceClient()

        # Setup request
        feed = {}
        update_mask = {}

        with pytest.raises(CustomException):
            client.update_feed(feed, update_mask)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p4beta1/proto/assets.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.rpc import code_pb2 as google_dot_rpc_dot_code__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p4beta1/proto/assets.proto",
    package="google.cloud.asset.v1p4beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p4beta1B\nAssetProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p4beta1;asset\370\001\001\252\002\034Google.Cloud.Asset.V1P4Beta1\312\002\034Google\\Cloud\\Asset\\V1p4beta1",
    serialized_pb=b'\n/google/cloud/asset_v1p4beta1/proto/assets.proto\x12\x1cgoogle.cloud.asset.v1p4beta1\x1a\x1agoogle/iam/v1/policy.proto\x1a\x15google/rpc/code.proto\x1a\x1cgoogle/api/annotations.proto"\x95\n\n\x17IamPolicyAnalysisResult\x12#\n\x1b\x61ttached_resource_full_name\x18\x01 \x01(\t\x12+\n\x0biam_binding\x18\x02 \x01(\x0b\x32\x16.google.iam.v1.Binding\x12\x65\n\x14\x61\x63\x63\x65ss_control_lists\x18\x03 \x03(\x0b\x32G.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList\x12Y\n\ridentity_list\x18\x04 \x01(\x0b\x32\x42.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.IdentityList\x12\x16\n\x0e\x66ully_explored\x18\x05 \x01(\x08\x1a>\n\rAnalysisState\x12\x1e\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x10.google.rpc.Code\x12\r\n\x05\x63\x61use\x18\x02 \x01(\t\x1a\x83\x01\n\x08Resource\x12\x1a\n\x12\x66ull_resource_name\x18\x01 \x01(\t\x12[\n\x0e\x61nalysis_state\x18\x02 \x01(\x0b\x32\x43.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState\x1a\x9b\x01\n\x06\x41\x63\x63\x65ss\x12\x0e\n\x04role\x18\x01 \x01(\tH\x00\x12\x14\n\npermission\x18\x02 \x01(\tH\x00\x12[\n\x0e\x61nalysis_state\x18\x03 \x01(\x0b\x32\x43.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisStateB\x0e\n\x0coneof_access\x1a\x30\n\x04\x45\x64ge\x12\x13\n\x0bsource_node\x18\x01 \x01(\t\x12\x13\n\x0btarget_node\x18\x02 \x01(\t\x1au\n\x08Identity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12[\n\x0e\x61nalysis_state\x18\x02 \x01(\x0b\x32\x43.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState\x1a\x8a\x02\n\x11\x41\x63\x63\x65ssControlList\x12Q\n\tresources\x18\x01 \x03(\x0b\x32>.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Resource\x12N\n\x08\x61\x63\x63\x65sses\x18\x02 \x03(\x0b\x32<.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access\x12R\n\x0eresource_edges\x18\x03 \x03(\x0b\x32:.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge\x1a\xb3\x01\n\x0cIdentityList\x12R\n\nidentities\x18\x01 \x03(\x0b\x32>.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Identity\x12O\n\x0bgroup_edges\x18\x02 \x03(\x0b\x32:.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.EdgeB\xb4\x01\n com.google.cloud.asset.v1p4beta1B\nAssetProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p4beta1;asset\xf8\x01\x01\xaa\x02\x1cGoogle.Cloud.Asset.V1P4Beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\V1p4beta1b\x06proto3',
    dependencies=[
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_rpc_dot_code__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_IAMPOLICYANALYSISRESULT_ANALYSISSTATE = _descriptor.Descriptor(
    name="AnalysisState",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState.code",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="cause",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState.cause",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=490,
    serialized_end=552,
)

_IAMPOLICYANALYSISRESULT_RESOURCE = _descriptor.Descriptor(
    name="Resource",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Resource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="full_resource_name",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Resource.full_resource_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_state",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Resource.analysis_state",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=555,
    serialized_end=686,
)

_IAMPOLICYANALYSISRESULT_ACCESS = _descriptor.Descriptor(
    name="Access",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="role",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access.role",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="permission",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access.permission",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_state",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access.analysis_state",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="oneof_access",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access.oneof_access",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=689,
    serialized_end=844,
)

_IAMPOLICYANALYSISRESULT_EDGE = _descriptor.Descriptor(
    name="Edge",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="source_node",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge.source_node",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="target_node",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge.target_node",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=846,
    serialized_end=894,
)

_IAMPOLICYANALYSISRESULT_IDENTITY = _descriptor.Descriptor(
    name="Identity",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Identity",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Identity.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_state",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Identity.analysis_state",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=896,
    serialized_end=1013,
)

_IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST = _descriptor.Descriptor(
    name="AccessControlList",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="resources",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList.resources",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="accesses",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList.accesses",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource_edges",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList.resource_edges",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1016,
    serialized_end=1282,
)

_IAMPOLICYANALYSISRESULT_IDENTITYLIST = _descriptor.Descriptor(
    name="IdentityList",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.IdentityList",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="identities",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.IdentityList.identities",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="group_edges",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.IdentityList.group_edges",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1285,
    serialized_end=1464,
)

_IAMPOLICYANALYSISRESULT = _descriptor.Descriptor(
    name="IamPolicyAnalysisResult",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="attached_resource_full_name",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.attached_resource_full_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="iam_binding",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.iam_binding",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="access_control_lists",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.access_control_lists",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="identity_list",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.identity_list",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fully_explored",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.fully_explored",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _IAMPOLICYANALYSISRESULT_ANALYSISSTATE,
        _IAMPOLICYANALYSISRESULT_RESOURCE,
        _IAMPOLICYANALYSISRESULT_ACCESS,
        _IAMPOLICYANALYSISRESULT_EDGE,
        _IAMPOLICYANALYSISRESULT_IDENTITY,
        _IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST,
        _IAMPOLICYANALYSISRESULT_IDENTITYLIST,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=163,
    serialized_end=1464,
)

_IAMPOLICYANALYSISRESULT_ANALYSISSTATE.fields_by_name[
    "code"
].enum_type = google_dot_rpc_dot_code__pb2._CODE
_IAMPOLICYANALYSISRESULT_ANALYSISSTATE.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_RESOURCE.fields_by_name[
    "analysis_state"
].message_type = _IAMPOLICYANALYSISRESULT_ANALYSISSTATE
_IAMPOLICYANALYSISRESULT_RESOURCE.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_ACCESS.fields_by_name[
    "analysis_state"
].message_type = _IAMPOLICYANALYSISRESULT_ANALYSISSTATE
_IAMPOLICYANALYSISRESULT_ACCESS.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_ACCESS.oneofs_by_name["oneof_access"].fields.append(
    _IAMPOLICYANALYSISRESULT_ACCESS.fields_by_name["role"]
)
_IAMPOLICYANALYSISRESULT_ACCESS.fields_by_name[
    "role"
].containing_oneof = _IAMPOLICYANALYSISRESULT_ACCESS.oneofs_by_name["oneof_access"]
_IAMPOLICYANALYSISRESULT_ACCESS.oneofs_by_name["oneof_access"].fields.append(
    _IAMPOLICYANALYSISRESULT_ACCESS.fields_by_name["permission"]
)
_IAMPOLICYANALYSISRESULT_ACCESS.fields_by_name[
    "permission"
].containing_oneof = _IAMPOLICYANALYSISRESULT_ACCESS.oneofs_by_name["oneof_access"]
_IAMPOLICYANALYSISRESULT_EDGE.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_IDENTITY.fields_by_name[
    "analysis_state"
].message_type = _IAMPOLICYANALYSISRESULT_ANALYSISSTATE
_IAMPOLICYANALYSISRESULT_IDENTITY.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST.fields_by_name[
    "resources"
].message_type = _IAMPOLICYANALYSISRESULT_RESOURCE
_IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST.fields_by_name[
    "accesses"
].message_type = _IAMPOLICYANALYSISRESULT_ACCESS
_IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST.fields_by_name[
    "resource_edges"
].message_type = _IAMPOLICYANALYSISRESULT_EDGE
_IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT_IDENTITYLIST.fields_by_name[
    "identities"
].message_type = _IAMPOLICYANALYSISRESULT_IDENTITY
_IAMPOLICYANALYSISRESULT_IDENTITYLIST.fields_by_name[
    "group_edges"
].message_type = _IAMPOLICYANALYSISRESULT_EDGE
_IAMPOLICYANALYSISRESULT_IDENTITYLIST.containing_type = _IAMPOLICYANALYSISRESULT
_IAMPOLICYANALYSISRESULT.fields_by_name[
    "iam_binding"
].message_type = (
    google_dot_iam_dot_v1_dot_policy__pb2.google_dot_iam_dot_v1_dot_policy__pb2._BINDING
)
_IAMPOLICYANALYSISRESULT.fields_by_name[
    "access_control_lists"
].message_type = _IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST
_IAMPOLICYANALYSISRESULT.fields_by_name[
    "identity_list"
].message_type = _IAMPOLICYANALYSISRESULT_IDENTITYLIST
DESCRIPTOR.message_types_by_name["IamPolicyAnalysisResult"] = _IAMPOLICYANALYSISRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IamPolicyAnalysisResult = _reflection.GeneratedProtocolMessageType(
    "IamPolicyAnalysisResult",
    (_message.Message,),
    {
        "AnalysisState": _reflection.GeneratedProtocolMessageType(
            "AnalysisState",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_ANALYSISSTATE,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """Represents analysis state of each node in the result graph
    or non-critical errors in the response.
    
    
    Attributes:
        code:
            The Google standard error code that best describes the state.
            For example: - OK means the node has been successfully
            explored; - PERMISSION_DENIED means an access denied error is
            encountered; - DEADLINE_EXCEEDED means the node hasn’t been
            explored in time;
        cause:
            The human-readable description of the cause of failure.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState)
            },
        ),
        "Resource": _reflection.GeneratedProtocolMessageType(
            "Resource",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_RESOURCE,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """A GCP resource that appears in an access control list.
    
    
    Attributes:
        full_resource_name:
            The `full resource name <https://aip.dev/122#full-resource-
            names>`__.
        analysis_state:
            The analysis state of this resource node.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Resource)
            },
        ),
        "Access": _reflection.GeneratedProtocolMessageType(
            "Access",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_ACCESS,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """A role or permission that appears in an access control
    list.
    
    
    Attributes:
        role:
            The role.
        permission:
            The permission.
        analysis_state:
            The analysis state of this access node.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Access)
            },
        ),
        "Edge": _reflection.GeneratedProtocolMessageType(
            "Edge",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_EDGE,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """A directional edge.
    
    
    Attributes:
        source_node:
            The source node of the edge.
        target_node:
            The target node of the edge.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge)
            },
        ),
        "Identity": _reflection.GeneratedProtocolMessageType(
            "Identity",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_IDENTITY,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """An identity that appears in an access control list.
    
    
    Attributes:
        name:
            The identity name in any form of members appear in `IAM policy
            binding
            <https://cloud.google.com/iam/reference/rest/v1/Binding>`__,
            such as: - user:foo@google.com - group:group1@google.com -
            serviceAccount:s1@prj1.iam.gserviceaccount.com -
            projectOwner:some_project_id - domain:google.com - allUsers -
            etc.
        analysis_state:
            The analysis state of this identity node.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Identity)
            },
        ),
        "AccessControlList": _reflection.GeneratedProtocolMessageType(
            "AccessControlList",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_ACCESSCONTROLLIST,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """An access control list, derived from the above IAM policy
    binding, which contains a set of resources and accesses. May include one
    item from each set to compose an access control entry.
    
    NOTICE that there could be multiple access control lists for one IAM
    policy binding. The access control lists are created based on resource
    and access combinations.
    
    For example, assume we have the following cases in one IAM policy
    binding: - Permission P1 and P2 apply to resource R1 and R2; -
    Permission P3 applies to resource R2 and R3;
    
    This will result in the following access control lists: -
    AccessControlList 1: [R1, R2], [P1, P2] - AccessControlList 2: [R2, R3],
    [P3]
    
    
    Attributes:
        resources:
            The resources that match one of the following conditions: -
            The resource_selector, if it is specified in request; -
            Otherwise, resources reachable from the policy attached
            resource.
        accesses:
            The accesses that match one of the following conditions: - The
            access_selector, if it is specified in request; - Otherwise,
            access specifiers reachable from the policy binding’s role.
        resource_edges:
            Resource edges of the graph starting from the policy attached
            resource to any descendant resources. The [Edge.source_node][g
            oogle.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.Edge.sourc
            e_node] contains the full resource name of a parent resource
            and [Edge.target_node][google.cloud.asset.v1p4beta1.IamPolicyA
            nalysisResult.Edge.target_node] contains the full resource
            name of a child resource. This field is present only if the
            output_resource_edges option is enabled in request.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AccessControlList)
            },
        ),
        "IdentityList": _reflection.GeneratedProtocolMessageType(
            "IdentityList",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISRESULT_IDENTITYLIST,
                "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
                "__doc__": """
    Attributes:
        identities:
            Only the identities that match one of the following conditions
            will be presented: - The identity_selector, if it is specified
            in request; - Otherwise, identities reachable from the policy
            binding’s members.
        group_edges:
            Group identity edges of the graph starting from the binding’s
            group members to any node of the [identities][google.cloud.ass
            et.v1p4beta1.IamPolicyAnalysisResult.IdentityList.identities].
            The [Edge.source_node][google.cloud.asset.v1p4beta1.IamPolicyA
            nalysisResult.Edge.source_node] contains a group, such as
            “group:parent@google.com”. The [Edge.target_node][google.cloud
            .asset.v1p4beta1.IamPolicyAnalysisResult.Edge.target_node]
            contains a member of the group, such as
            “group:child@google.com” or “user:foo@google.com”. This field
            is present only if the output_group_edges option is enabled in
            request.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.IdentityList)
            },
        ),
        "DESCRIPTOR": _IAMPOLICYANALYSISRESULT,
        "__module__": "google.cloud.asset_v1p4beta1.proto.assets_pb2",
        "__doc__": """IAM Policy analysis result, consisting of one IAM policy
  binding and derived access control lists.
  
  
  Attributes:
      attached_resource_full_name:
          The full name of the resource to which the [iam_binding][googl
          e.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.iam_binding]
          policy attaches.
      iam_binding:
          The Cloud IAM policy binding under analysis.
      access_control_lists:
          The access control lists derived from the [iam_binding][google
          .cloud.asset.v1p4beta1.IamPolicyAnalysisResult.iam_binding]
          that match or potentially match resource and access selectors
          specified in the request.
      identity_list:
          The identity list derived from members of the [iam_binding][go
          ogle.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.iam_binding
          ] that match or potentially match identity selector specified
          in the request.
      fully_explored:
          Represents whether all nodes in the transitive closure of the 
          [iam_binding][google.cloud.asset.v1p4beta1.IamPolicyAnalysisRe
          sult.iam_binding] node have been explored.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult)
    },
)
_sym_db.RegisterMessage(IamPolicyAnalysisResult)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.AnalysisState)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.Resource)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.Access)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.Edge)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.Identity)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.AccessControlList)
_sym_db.RegisterMessage(IamPolicyAnalysisResult.IdentityList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class Code(enum.IntEnum):
    """
    The canonical error codes for gRPC APIs.

    Sometimes multiple error codes may apply. Services should return the
    most specific error code that applies. For example, prefer
    ``OUT_OF_RANGE`` over ``FAILED_PRECONDITION`` if both codes apply.
    Similarly prefer ``NOT_FOUND`` or ``ALREADY_EXISTS`` over
    ``FAILED_PRECONDITION``.

    Attributes:
      OK (int): Not an error; returned on success

      HTTP Mapping: 200 OK
      CANCELLED (int): The operation was cancelled, typically by the caller.

      HTTP Mapping: 499 Client Closed Request
      UNKNOWN (int): Unknown error. For example, this error may be returned when a
      ``Status`` value received from another address space belongs to an error
      space that is not known in this address space. Also errors raised by
      APIs that do not return enough error information may be converted to
      this error.

      HTTP Mapping: 500 Internal Server Error
      INVALID_ARGUMENT (int): The client specified an invalid argument. Note that this differs
      from ``FAILED_PRECONDITION``. ``INVALID_ARGUMENT`` indicates arguments
      that are problematic regardless of the state of the system (e.g., a
      malformed file name).

      HTTP Mapping: 400 Bad Request
      DEADLINE_EXCEEDED (int): The deadline expired before the operation could complete. For operations
      that change the state of the system, this error may be returned
      even if the operation has completed successfully.  For example, a
      successful response from a server could have been delayed long
      enough for the deadline to expire.

      HTTP Mapping: 504 Gateway Timeout
      NOT_FOUND (int): Some requested entity (e.g., file or directory) was not found.

      Note to server developers: if a request is denied for an entire class of
      users, such as gradual feature rollout or undocumented whitelist,
      ``NOT_FOUND`` may be used. If a request is denied for some users within
      a class of users, such as user-based access control,
      ``PERMISSION_DENIED`` must be used.

      HTTP Mapping: 404 Not Found
      ALREADY_EXISTS (int): The entity that a client attempted to create (e.g., file or directory)
      already exists.

      HTTP Mapping: 409 Conflict
      PERMISSION_DENIED (int): The caller does not have permission to execute the specified
      operation. ``PERMISSION_DENIED`` must not be used for rejections caused
      by exhausting some resource (use ``RESOURCE_EXHAUSTED`` instead for
      those errors). ``PERMISSION_DENIED`` must not be used if the caller can
      not be identified (use ``UNAUTHENTICATED`` instead for those errors).
      This error code does not imply the request is valid or the requested
      entity exists or satisfies other pre-conditions.

      HTTP Mapping: 403 Forbidden
      UNAUTHENTICATED (int): The request does not have valid authentication credentials for the
      operation.

      HTTP Mapping: 401 Unauthorized
      RESOURCE_EXHAUSTED (int): Some resource has been exhausted, perhaps a per-user quota, or
      perhaps the entire file system is out of space.

      HTTP Mapping: 429 Too Many Requests
      FAILED_PRECONDITION (int): The operation was rejected because the system is not in a state
      required for the operation's execution. For example, the directory to be
      deleted is non-empty, an rmdir operation is applied to a non-directory,
      etc.

      Service implementors can use the following guidelines to decide between
      ``FAILED_PRECONDITION``, ``ABORTED``, and ``UNAVAILABLE``: (a) Use
      ``UNAVAILABLE`` if the client can retry just the failing call. (b) Use
      ``ABORTED`` if the client should retry at a higher level (e.g., when a
      client-specified test-and-set fails, indicating the client should
      restart a read-modify-write sequence). (c) Use ``FAILED_PRECONDITION``
      if the client should not retry until the system state has been
      explicitly fixed. E.g., if an "rmdir" fails because the directory is
      non-empty, ``FAILED_PRECONDITION`` should be returned since the client
      should not retry unless the files are deleted from the directory.

      HTTP Mapping: 400 Bad Request
      ABORTED (int): The operation was aborted, typically due to a concurrency issue such
      as a sequencer check failure or transaction abort.

      See the guidelines above for deciding between ``FAILED_PRECONDITION``,
      ``ABORTED``, and ``UNAVAILABLE``.

      HTTP Mapping: 409 Conflict
      OUT_OF_RANGE (int): The operation was attempted past the valid range. E.g., seeking or
      reading past end-of-file.

      Unlike ``INVALID_ARGUMENT``, this error indicates a problem that may be
      fixed if the system state changes. For example, a 32-bit file system
      will generate ``INVALID_ARGUMENT`` if asked to read at an offset that is
      not in the range [0,2^32-1], but it will generate ``OUT_OF_RANGE`` if
      asked to read from an offset past the current file size.

      There is a fair bit of overlap between ``FAILED_PRECONDITION`` and
      ``OUT_OF_RANGE``. We recommend using ``OUT_OF_RANGE`` (the more specific
      error) when it applies so that callers who are iterating through a space
      can easily look for an ``OUT_OF_RANGE`` error to detect when they are
      done.

      HTTP Mapping: 400 Bad Request
      UNIMPLEMENTED (int): The operation is not implemented or is not supported/enabled in this
      service.

      HTTP Mapping: 501 Not Implemented
      INTERNAL (int): Internal errors.  This means that some invariants expected by the
      underlying system have been broken.  This error code is reserved
      for serious errors.

      HTTP Mapping: 500 Internal Server Error
      UNAVAILABLE (int): The service is currently unavailable. This is most likely a
      transient condition, which can be corrected by retrying with a backoff.
      Note that it is not always safe to retry non-idempotent operations.

      See the guidelines above for deciding between ``FAILED_PRECONDITION``,
      ``ABORTED``, and ``UNAVAILABLE``.

      HTTP Mapping: 503 Service Unavailable
      DATA_LOSS (int): Unrecoverable data loss or corruption.

      HTTP Mapping: 500 Internal Server Error
    """

    OK = 0
    CANCELLED = 1
    UNKNOWN = 2
    INVALID_ARGUMENT = 3
    DEADLINE_EXCEEDED = 4
    NOT_FOUND = 5
    ALREADY_EXISTS = 6
    PERMISSION_DENIED = 7
    UNAUTHENTICATED = 16
    RESOURCE_EXHAUSTED = 8
    FAILED_PRECONDITION = 9
    ABORTED = 10
    OUT_OF_RANGE = 11
    UNIMPLEMENTED = 12
    INTERNAL = 13
    UNAVAILABLE = 14
    DATA_LOSS = 15



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p1beta1/proto/asset_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.cloud.asset_v1p1beta1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_assets__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p1beta1/proto/asset_service.proto",
    package="google.cloud.asset.v1p1beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p1beta1B\021AssetServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p1beta1;asset\252\002\034Google.Cloud.Asset.V1P1Beta1\312\002\034Google\\Cloud\\Asset\\V1p1beta1",
    serialized_pb=b'\n6google/cloud/asset_v1p1beta1/proto/asset_service.proto\x12\x1cgoogle.cloud.asset.v1p1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a/google/cloud/asset_v1p1beta1/proto/assets.proto"\xa5\x01\n\x19SearchAllResourcesRequest\x12\x12\n\x05scope\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05query\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x61sset_types\x18\x03 \x03(\tB\x03\xe0\x41\x01\x12\x16\n\tpage_size\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x05 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\n \x01(\tB\x03\xe0\x41\x01"~\n\x1aSearchAllResourcesResponse\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.google.cloud.asset.v1p1beta1.StandardResourceMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"v\n\x1bSearchAllIamPoliciesRequest\x12\x12\n\x05scope\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05query\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x16\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01"}\n\x1cSearchAllIamPoliciesResponse\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32\x33.google.cloud.asset.v1p1beta1.IamPolicySearchResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x89\x04\n\x0c\x41ssetService\x12\xd5\x01\n\x12SearchAllResources\x12\x37.google.cloud.asset.v1p1beta1.SearchAllResourcesRequest\x1a\x38.google.cloud.asset.v1p1beta1.SearchAllResourcesResponse"L\x82\xd3\xe4\x93\x02,\x12*/v1p1beta1/{scope=*/*}/resources:searchAll\xda\x41\x17scope,query,asset_types\x12\xd1\x01\n\x14SearchAllIamPolicies\x12\x39.google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest\x1a:.google.cloud.asset.v1p1beta1.SearchAllIamPoliciesResponse"B\x82\xd3\xe4\x93\x02.\x12,/v1p1beta1/{scope=*/*}/iamPolicies:searchAll\xda\x41\x0bscope,query\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb8\x01\n com.google.cloud.asset.v1p1beta1B\x11\x41ssetServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p1beta1;asset\xaa\x02\x1cGoogle.Cloud.Asset.V1P1Beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\V1p1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,
    ],
)


_SEARCHALLRESOURCESREQUEST = _descriptor.Descriptor(
    name="SearchAllResourcesRequest",
    full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.scope",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.query",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.page_token",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesRequest.order_by",
            index=5,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=226,
    serialized_end=391,
)


_SEARCHALLRESOURCESRESPONSE = _descriptor.Descriptor(
    name="SearchAllResourcesResponse",
    full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="results",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesResponse.results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.asset.v1p1beta1.SearchAllResourcesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=393,
    serialized_end=519,
)


_SEARCHALLIAMPOLICIESREQUEST = _descriptor.Descriptor(
    name="SearchAllIamPoliciesRequest",
    full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest.scope",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest.query",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest.page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=521,
    serialized_end=639,
)


_SEARCHALLIAMPOLICIESRESPONSE = _descriptor.Descriptor(
    name="SearchAllIamPoliciesResponse",
    full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="results",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesResponse.results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.asset.v1p1beta1.SearchAllIamPoliciesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=641,
    serialized_end=766,
)

_SEARCHALLRESOURCESRESPONSE.fields_by_name[
    "results"
].message_type = (
    google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_assets__pb2._STANDARDRESOURCEMETADATA
)
_SEARCHALLIAMPOLICIESRESPONSE.fields_by_name[
    "results"
].message_type = (
    google_dot_cloud_dot_asset__v1p1beta1_dot_proto_dot_assets__pb2._IAMPOLICYSEARCHRESULT
)
DESCRIPTOR.message_types_by_name[
    "SearchAllResourcesRequest"
] = _SEARCHALLRESOURCESREQUEST
DESCRIPTOR.message_types_by_name[
    "SearchAllResourcesResponse"
] = _SEARCHALLRESOURCESRESPONSE
DESCRIPTOR.message_types_by_name[
    "SearchAllIamPoliciesRequest"
] = _SEARCHALLIAMPOLICIESREQUEST
DESCRIPTOR.message_types_by_name[
    "SearchAllIamPoliciesResponse"
] = _SEARCHALLIAMPOLICIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchAllResourcesRequest = _reflection.GeneratedProtocolMessageType(
    "SearchAllResourcesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHALLRESOURCESREQUEST,
        "__module__": "google.cloud.asset_v1p1beta1.proto.asset_service_pb2",
        "__doc__": """Search all resources request.
  
  
  Attributes:
      scope:
          Required. The relative name of an asset. The search is limited
          to the resources within the ``scope``. The allowed value must
          be: \* Organization number (such as “organizations/123”) \*
          Folder number(such as “folders/1234”) \* Project number (such
          as “projects/12345”) \* Project id (such as “projects/abc”)
      query:
          Optional. The query statement.
      asset_types:
          Optional. A list of asset types that this request searches
          for. If empty, it will search all the supported asset types.
      page_size:
          Optional. The page size for search result pagination. Page
          size is capped at 500 even if a larger value is given. If set
          to zero, server will pick an appropriate default. Returned
          results may be fewer than requested. When this happens, there
          could be more results as long as ``next_page_token`` is
          returned.
      page_token:
          Optional. If present, then retrieve the next batch of results
          from the preceding call to this method. ``page_token`` must be
          the value of ``next_page_token`` from the previous response.
          The values of all other method parameters, must be identical
          to those in the previous call.
      order_by:
          Optional. A comma separated list of fields specifying the
          sorting order of the results. The default order is ascending.
          Add " desc" after the field name to indicate descending order.
          Redundant space characters are ignored. For example, " foo ,
          bar desc ".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p1beta1.SearchAllResourcesRequest)
    },
)
_sym_db.RegisterMessage(SearchAllResourcesRequest)

SearchAllResourcesResponse = _reflection.GeneratedProtocolMessageType(
    "SearchAllResourcesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHALLRESOURCESRESPONSE,
        "__module__": "google.cloud.asset_v1p1beta1.proto.asset_service_pb2",
        "__doc__": """Search all resources response.
  
  
  Attributes:
      results:
          A list of resource that match the search query.
      next_page_token:
          If there are more results than those appearing in this
          response, then ``next_page_token`` is included. To get the
          next set of results, call this method again using the value of
          ``next_page_token`` as ``page_token``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p1beta1.SearchAllResourcesResponse)
    },
)
_sym_db.RegisterMessage(SearchAllResourcesResponse)

SearchAllIamPoliciesRequest = _reflection.GeneratedProtocolMessageType(
    "SearchAllIamPoliciesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHALLIAMPOLICIESREQUEST,
        "__module__": "google.cloud.asset_v1p1beta1.proto.asset_service_pb2",
        "__doc__": """Search all IAM policies request.
  
  
  Attributes:
      scope:
          Required. The relative name of an asset. The search is limited
          to the resources within the ``scope``. The allowed value must
          be: \* Organization number (such as “organizations/123”) \*
          Folder number(such as “folders/1234”) \* Project number (such
          as “projects/12345”) \* Project id (such as “projects/abc”)
      query:
          Optional. The query statement. Examples: \*
          “policy:myuser@mydomain.com” \* “policy:(myuser@mydomain.com
          viewer)”
      page_size:
          Optional. The page size for search result pagination. Page
          size is capped at 500 even if a larger value is given. If set
          to zero, server will pick an appropriate default. Returned
          results may be fewer than requested. When this happens, there
          could be more results as long as ``next_page_token`` is
          returned.
      page_token:
          Optional. If present, retrieve the next batch of results from
          the preceding call to this method. ``page_token`` must be the
          value of ``next_page_token`` from the previous response. The
          values of all other method parameters must be identical to
          those in the previous call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p1beta1.SearchAllIamPoliciesRequest)
    },
)
_sym_db.RegisterMessage(SearchAllIamPoliciesRequest)

SearchAllIamPoliciesResponse = _reflection.GeneratedProtocolMessageType(
    "SearchAllIamPoliciesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHALLIAMPOLICIESRESPONSE,
        "__module__": "google.cloud.asset_v1p1beta1.proto.asset_service_pb2",
        "__doc__": """Search all IAM policies response.
  
  
  Attributes:
      results:
          A list of IamPolicy that match the search query. Related
          information such as the associated resource is returned along
          with the policy.
      next_page_token:
          Set if there are more results than those appearing in this
          response; to get the next set of results, call this method
          again, using this value as the ``page_token``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p1beta1.SearchAllIamPoliciesResponse)
    },
)
_sym_db.RegisterMessage(SearchAllIamPoliciesResponse)


DESCRIPTOR._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["scope"]._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["query"]._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["asset_types"]._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["page_size"]._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["page_token"]._options = None
_SEARCHALLRESOURCESREQUEST.fields_by_name["order_by"]._options = None
_SEARCHALLIAMPOLICIESREQUEST.fields_by_name["scope"]._options = None
_SEARCHALLIAMPOLICIESREQUEST.fields_by_name["query"]._options = None
_SEARCHALLIAMPOLICIESREQUEST.fields_by_name["page_size"]._options = None
_SEARCHALLIAMPOLICIESREQUEST.fields_by_name["page_token"]._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1p1beta1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=769,
    serialized_end=1290,
    methods=[
        _descriptor.MethodDescriptor(
            name="SearchAllResources",
            full_name="google.cloud.asset.v1p1beta1.AssetService.SearchAllResources",
            index=0,
            containing_service=None,
            input_type=_SEARCHALLRESOURCESREQUEST,
            output_type=_SEARCHALLRESOURCESRESPONSE,
            serialized_options=b"\202\323\344\223\002,\022*/v1p1beta1/{scope=*/*}/resources:searchAll\332A\027scope,query,asset_types",
        ),
        _descriptor.MethodDescriptor(
            name="SearchAllIamPolicies",
            full_name="google.cloud.asset.v1p1beta1.AssetService.SearchAllIamPolicies",
            index=1,
            containing_service=None,
            input_type=_SEARCHALLIAMPOLICIESREQUEST,
            output_type=_SEARCHALLIAMPOLICIESRESPONSE,
            serialized_options=b"\202\323\344\223\002.\022,/v1p1beta1/{scope=*/*}/iamPolicies:searchAll\332A\013scope,query",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1p4beta1/proto/asset_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.cloud.asset_v1p4beta1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_assets__pb2,
)
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1p4beta1/proto/asset_service.proto",
    package="google.cloud.asset.v1p4beta1",
    syntax="proto3",
    serialized_options=b"\n com.google.cloud.asset.v1p4beta1B\021AssetServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p4beta1;asset\252\002\034Google.Cloud.Asset.V1P4Beta1\312\002\034Google\\Cloud\\Asset\\V1p4beta1",
    serialized_pb=b'\n6google/cloud/asset_v1p4beta1/proto/asset_service.proto\x12\x1cgoogle.cloud.asset.v1p4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a/google/cloud/asset_v1p4beta1/proto/assets.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a#google/longrunning/operations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/api/client.proto"\xfe\x03\n\x16IamPolicyAnalysisQuery\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x65\n\x11resource_selector\x18\x02 \x01(\x0b\x32\x45.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.ResourceSelectorB\x03\xe0\x41\x01\x12\x65\n\x11identity_selector\x18\x03 \x01(\x0b\x32\x45.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.IdentitySelectorB\x03\xe0\x41\x01\x12\x61\n\x0f\x61\x63\x63\x65ss_selector\x18\x04 \x01(\x0b\x32\x43.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelectorB\x03\xe0\x41\x01\x1a\x33\n\x10ResourceSelector\x12\x1f\n\x12\x66ull_resource_name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x1a)\n\x10IdentitySelector\x12\x15\n\x08identity\x18\x01 \x01(\tB\x03\xe0\x41\x02\x1a>\n\x0e\x41\x63\x63\x65ssSelector\x12\x12\n\x05roles\x18\x01 \x03(\tB\x03\xe0\x41\x01\x12\x18\n\x0bpermissions\x18\x02 \x03(\tB\x03\xe0\x41\x01"\xd7\x03\n\x17\x41nalyzeIamPolicyRequest\x12Q\n\x0e\x61nalysis_query\x18\x01 \x01(\x0b\x32\x34.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQueryB\x03\xe0\x41\x02\x12S\n\x07options\x18\x02 \x01(\x0b\x32=.google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.OptionsB\x03\xe0\x41\x01\x1a\x93\x02\n\x07Options\x12\x1a\n\rexpand_groups\x18\x01 \x01(\x08\x42\x03\xe0\x41\x01\x12\x19\n\x0c\x65xpand_roles\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1d\n\x10\x65xpand_resources\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x12"\n\x15output_resource_edges\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1f\n\x12output_group_edges\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01\x12\x32\n%analyze_service_account_impersonation\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01\x12\x39\n\x11\x65xecution_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x03\xe0\x41\x01"\xbc\x04\n\x18\x41nalyzeIamPolicyResponse\x12_\n\rmain_analysis\x18\x01 \x01(\x0b\x32H.google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis\x12x\n&service_account_impersonation_analysis\x18\x02 \x03(\x0b\x32H.google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis\x12\x16\n\x0e\x66ully_explored\x18\x03 \x01(\x08\x12`\n\x13non_critical_errors\x18\x04 \x03(\x0b\x32\x43.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult.AnalysisState\x1a\xca\x01\n\x11IamPolicyAnalysis\x12L\n\x0e\x61nalysis_query\x18\x01 \x01(\x0b\x32\x34.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery\x12O\n\x10\x61nalysis_results\x18\x02 \x03(\x0b\x32\x35.google.cloud.asset.v1p4beta1.IamPolicyAnalysisResult\x12\x16\n\x0e\x66ully_explored\x18\x03 \x01(\x08"\xb9\x01\n\x1dIamPolicyAnalysisOutputConfig\x12\x65\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32J.google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.GcsDestinationH\x00\x1a"\n\x0eGcsDestination\x12\x10\n\x03uri\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\r\n\x0b\x64\x65stination"\x83\x04\n\x1e\x45xportIamPolicyAnalysisRequest\x12Q\n\x0e\x61nalysis_query\x18\x01 \x01(\x0b\x32\x34.google.cloud.asset.v1p4beta1.IamPolicyAnalysisQueryB\x03\xe0\x41\x02\x12Z\n\x07options\x18\x02 \x01(\x0b\x32\x44.google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.OptionsB\x03\xe0\x41\x01\x12W\n\routput_config\x18\x03 \x01(\x0b\x32;.google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfigB\x03\xe0\x41\x02\x1a\xd8\x01\n\x07Options\x12\x1a\n\rexpand_groups\x18\x01 \x01(\x08\x42\x03\xe0\x41\x01\x12\x19\n\x0c\x65xpand_roles\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1d\n\x10\x65xpand_resources\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x12"\n\x15output_resource_edges\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1f\n\x12output_group_edges\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01\x12\x32\n%analyze_service_account_impersonation\x18\x06 \x01(\x08\x42\x03\xe0\x41\x01"u\n\x1f\x45xportIamPolicyAnalysisResponse\x12R\n\routput_config\x18\x01 \x01(\x0b\x32;.google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig2\xe5\x04\n\x0c\x41ssetService\x12\xc2\x01\n\x10\x41nalyzeIamPolicy\x12\x35.google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest\x1a\x36.google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse"?\x82\xd3\xe4\x93\x02\x39\x12\x37/v1p4beta1/{analysis_query.parent=*/*}:analyzeIamPolicy\x12\xc0\x02\n\x17\x45xportIamPolicyAnalysis\x12<.google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest\x1a\x1d.google.longrunning.Operation"\xc7\x01\x82\xd3\xe4\x93\x02\x43">/v1p4beta1/{analysis_query.parent=*/*}:exportIamPolicyAnalysis:\x01*\xca\x41{\n<google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisResponse\x12;google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb8\x01\n com.google.cloud.asset.v1p4beta1B\x11\x41ssetServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/asset/v1p4beta1;asset\xaa\x02\x1cGoogle.Cloud.Asset.V1P4Beta1\xca\x02\x1cGoogle\\Cloud\\Asset\\V1p4beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
    ],
)


_IAMPOLICYANALYSISQUERY_RESOURCESELECTOR = _descriptor.Descriptor(
    name="ResourceSelector",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.ResourceSelector",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="full_resource_name",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.ResourceSelector.full_resource_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=675,
    serialized_end=726,
)

_IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR = _descriptor.Descriptor(
    name="IdentitySelector",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.IdentitySelector",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="identity",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.IdentitySelector.identity",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=728,
    serialized_end=769,
)

_IAMPOLICYANALYSISQUERY_ACCESSSELECTOR = _descriptor.Descriptor(
    name="AccessSelector",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelector",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="roles",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelector.roles",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="permissions",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelector.permissions",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=771,
    serialized_end=833,
)

_IAMPOLICYANALYSISQUERY = _descriptor.Descriptor(
    name="IamPolicyAnalysisQuery",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="resource_selector",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.resource_selector",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="identity_selector",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.identity_selector",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="access_selector",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.access_selector",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[
        _IAMPOLICYANALYSISQUERY_RESOURCESELECTOR,
        _IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR,
        _IAMPOLICYANALYSISQUERY_ACCESSSELECTOR,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=323,
    serialized_end=833,
)


_ANALYZEIAMPOLICYREQUEST_OPTIONS = _descriptor.Descriptor(
    name="Options",
    full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="expand_groups",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.expand_groups",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expand_roles",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.expand_roles",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expand_resources",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.expand_resources",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_resource_edges",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.output_resource_edges",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_group_edges",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.output_group_edges",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analyze_service_account_impersonation",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.analyze_service_account_impersonation",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="execution_timeout",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options.execution_timeout",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1032,
    serialized_end=1307,
)

_ANALYZEIAMPOLICYREQUEST = _descriptor.Descriptor(
    name="AnalyzeIamPolicyRequest",
    full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_query",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.analysis_query",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="options",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_ANALYZEIAMPOLICYREQUEST_OPTIONS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=836,
    serialized_end=1307,
)


_ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS = _descriptor.Descriptor(
    name="IamPolicyAnalysis",
    full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_query",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis.analysis_query",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_results",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis.analysis_results",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fully_explored",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis.fully_explored",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1680,
    serialized_end=1882,
)

_ANALYZEIAMPOLICYRESPONSE = _descriptor.Descriptor(
    name="AnalyzeIamPolicyResponse",
    full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="main_analysis",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.main_analysis",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="service_account_impersonation_analysis",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.service_account_impersonation_analysis",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fully_explored",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.fully_explored",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="non_critical_errors",
            full_name="google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.non_critical_errors",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1310,
    serialized_end=1882,
)


_IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.GcsDestination.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2021,
    serialized_end=2055,
)

_IAMPOLICYANALYSISOUTPUTCONFIG = _descriptor.Descriptor(
    name="IamPolicyAnalysisOutputConfig",
    full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1885,
    serialized_end=2070,
)


_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS = _descriptor.Descriptor(
    name="Options",
    full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="expand_groups",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.expand_groups",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expand_roles",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.expand_roles",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="expand_resources",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.expand_resources",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_resource_edges",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.output_resource_edges",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_group_edges",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.output_group_edges",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="analyze_service_account_impersonation",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options.analyze_service_account_impersonation",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1032,
    serialized_end=1248,
)

_EXPORTIAMPOLICYANALYSISREQUEST = _descriptor.Descriptor(
    name="ExportIamPolicyAnalysisRequest",
    full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_query",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.analysis_query",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="options",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.options",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.output_config",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2073,
    serialized_end=2588,
)


_EXPORTIAMPOLICYANALYSISRESPONSE = _descriptor.Descriptor(
    name="ExportIamPolicyAnalysisResponse",
    full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisResponse.output_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2590,
    serialized_end=2707,
)

_IAMPOLICYANALYSISQUERY_RESOURCESELECTOR.containing_type = _IAMPOLICYANALYSISQUERY
_IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR.containing_type = _IAMPOLICYANALYSISQUERY
_IAMPOLICYANALYSISQUERY_ACCESSSELECTOR.containing_type = _IAMPOLICYANALYSISQUERY
_IAMPOLICYANALYSISQUERY.fields_by_name[
    "resource_selector"
].message_type = _IAMPOLICYANALYSISQUERY_RESOURCESELECTOR
_IAMPOLICYANALYSISQUERY.fields_by_name[
    "identity_selector"
].message_type = _IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR
_IAMPOLICYANALYSISQUERY.fields_by_name[
    "access_selector"
].message_type = _IAMPOLICYANALYSISQUERY_ACCESSSELECTOR
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name[
    "execution_timeout"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_ANALYZEIAMPOLICYREQUEST_OPTIONS.containing_type = _ANALYZEIAMPOLICYREQUEST
_ANALYZEIAMPOLICYREQUEST.fields_by_name[
    "analysis_query"
].message_type = _IAMPOLICYANALYSISQUERY
_ANALYZEIAMPOLICYREQUEST.fields_by_name[
    "options"
].message_type = _ANALYZEIAMPOLICYREQUEST_OPTIONS
_ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS.fields_by_name[
    "analysis_query"
].message_type = _IAMPOLICYANALYSISQUERY
_ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS.fields_by_name[
    "analysis_results"
].message_type = (
    google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_assets__pb2._IAMPOLICYANALYSISRESULT
)
_ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS.containing_type = _ANALYZEIAMPOLICYRESPONSE
_ANALYZEIAMPOLICYRESPONSE.fields_by_name[
    "main_analysis"
].message_type = _ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS
_ANALYZEIAMPOLICYRESPONSE.fields_by_name[
    "service_account_impersonation_analysis"
].message_type = _ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS
_ANALYZEIAMPOLICYRESPONSE.fields_by_name[
    "non_critical_errors"
].message_type = (
    google_dot_cloud_dot_asset__v1p4beta1_dot_proto_dot_assets__pb2._IAMPOLICYANALYSISRESULT_ANALYSISSTATE
)
_IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION.containing_type = (
    _IAMPOLICYANALYSISOUTPUTCONFIG
)
_IAMPOLICYANALYSISOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].message_type = _IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION
_IAMPOLICYANALYSISOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _IAMPOLICYANALYSISOUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_IAMPOLICYANALYSISOUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _IAMPOLICYANALYSISOUTPUTCONFIG.oneofs_by_name["destination"]
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.containing_type = (
    _EXPORTIAMPOLICYANALYSISREQUEST
)
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name[
    "analysis_query"
].message_type = _IAMPOLICYANALYSISQUERY
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name[
    "options"
].message_type = _EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name[
    "output_config"
].message_type = _IAMPOLICYANALYSISOUTPUTCONFIG
_EXPORTIAMPOLICYANALYSISRESPONSE.fields_by_name[
    "output_config"
].message_type = _IAMPOLICYANALYSISOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["IamPolicyAnalysisQuery"] = _IAMPOLICYANALYSISQUERY
DESCRIPTOR.message_types_by_name["AnalyzeIamPolicyRequest"] = _ANALYZEIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name["AnalyzeIamPolicyResponse"] = _ANALYZEIAMPOLICYRESPONSE
DESCRIPTOR.message_types_by_name[
    "IamPolicyAnalysisOutputConfig"
] = _IAMPOLICYANALYSISOUTPUTCONFIG
DESCRIPTOR.message_types_by_name[
    "ExportIamPolicyAnalysisRequest"
] = _EXPORTIAMPOLICYANALYSISREQUEST
DESCRIPTOR.message_types_by_name[
    "ExportIamPolicyAnalysisResponse"
] = _EXPORTIAMPOLICYANALYSISRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IamPolicyAnalysisQuery = _reflection.GeneratedProtocolMessageType(
    "IamPolicyAnalysisQuery",
    (_message.Message,),
    {
        "ResourceSelector": _reflection.GeneratedProtocolMessageType(
            "ResourceSelector",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISQUERY_RESOURCESELECTOR,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """Specifies the resource to analyze for access policies,
    which may be set directly on the resource, or on ancestors such as
    organizations, folders or projects. At least one of
    [ResourceSelector][google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.ResourceSelector],
    [IdentitySelector][google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.IdentitySelector]
    or
    [AccessSelector][google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelector]
    must be specified in a request.
    
    
    Attributes:
        full_resource_name:
            Required. The `full resource name <https://cloud.google.com/ap
            is/design/resource_names#full_resource_name>`__ .
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.ResourceSelector)
            },
        ),
        "IdentitySelector": _reflection.GeneratedProtocolMessageType(
            "IdentitySelector",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """Specifies an identity for which to determine resource
    access, based on roles assigned either directly to them or to the groups
    they belong to, directly or indirectly.
    
    
    Attributes:
        identity:
            Required. The identity appear in the form of members in `IAM
            policy binding
            <https://cloud.google.com/iam/reference/rest/v1/Binding>`__.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.IdentitySelector)
            },
        ),
        "AccessSelector": _reflection.GeneratedProtocolMessageType(
            "AccessSelector",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISQUERY_ACCESSSELECTOR,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """Specifies roles and/or permissions to analyze, to
    determine both the identities possessing them and the resources they
    control. If multiple values are specified, results will include
    identities and resources matching any of them.
    
    
    Attributes:
        roles:
            Optional. The roles to appear in result.
        permissions:
            Optional. The permissions to appear in result.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery.AccessSelector)
            },
        ),
        "DESCRIPTOR": _IAMPOLICYANALYSISQUERY,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """IAM policy analysis query message.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. Only resources
          and IAM policies within the parent will be analyzed. This can
          only be an organization number (such as “organizations/123”)
          or a folder number (such as “folders/123”).
      resource_selector:
          Optional. Specifies a resource for analysis. Leaving it empty
          means ANY.
      identity_selector:
          Optional. Specifies an identity for analysis. Leaving it empty
          means ANY.
      access_selector:
          Optional. Specifies roles or permissions for analysis. Leaving
          it empty means ANY.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisQuery)
    },
)
_sym_db.RegisterMessage(IamPolicyAnalysisQuery)
_sym_db.RegisterMessage(IamPolicyAnalysisQuery.ResourceSelector)
_sym_db.RegisterMessage(IamPolicyAnalysisQuery.IdentitySelector)
_sym_db.RegisterMessage(IamPolicyAnalysisQuery.AccessSelector)

AnalyzeIamPolicyRequest = _reflection.GeneratedProtocolMessageType(
    "AnalyzeIamPolicyRequest",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _ANALYZEIAMPOLICYREQUEST_OPTIONS,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """Contains request options.
    
    
    Attributes:
        expand_groups:
            Optional. If true, the identities section of the result will
            expand any Google groups appearing in an IAM policy binding.
            If [identity_selector][] is specified, the identity in the
            result will be determined by the selector, and this flag will
            have no effect.  Default is false.
        expand_roles:
            Optional. If true, the access section of result will expand
            any roles appearing in IAM policy bindings to include their
            permissions.  If [access_selector][] is specified, the access
            section of the result will be determined by the selector, and
            this flag will have no effect.  Default is false.
        expand_resources:
            Optional. If true, the resource section of the result will
            expand any resource attached to an IAM policy to include
            resources lower in the resource hierarchy.  For example, if
            the request analyzes for which resources user A has permission
            P, and the results include an IAM policy with P on a GCP
            folder, the results will also include resources in that folder
            with permission P.  If [resource_selector][] is specified, the
            resource section of the result will be determined by the
            selector, and this flag will have no effect. Default is false.
        output_resource_edges:
            Optional. If true, the result will output resource edges,
            starting from the policy attached resource, to any expanded
            resources. Default is false.
        output_group_edges:
            Optional. If true, the result will output group identity
            edges, starting from the binding’s group members, to any
            expanded identities. Default is false.
        analyze_service_account_impersonation:
            Optional. If true, the response will include access analysis
            from identities to resources via service account
            impersonation. This is a very expensive operation, because
            many derived queries will be executed. We highly recommend you
            use ExportIamPolicyAnalysis rpc instead.  For example, if the
            request analyzes for which resources user A has permission P,
            and there’s an IAM policy states user A has
            iam.serviceAccounts.getAccessToken permission to a service
            account SA, and there’s another IAM policy states service
            account SA has permission P to a GCP folder F, then user A
            potentially has access to the GCP folder F. And those advanced
            analysis results will be included in [AnalyzeIamPolicyResponse
            .service_account_impersonation_analysis][google.cloud.asset.v1
            p4beta1.AnalyzeIamPolicyResponse.service_account_impersonation
            _analysis].  Another example, if the request analyzes for who
            has permission P to a GCP folder F, and there’s an IAM policy
            states user A has iam.serviceAccounts.actAs permission to a
            service account SA, and there’s another IAM policy states
            service account SA has permission P to the GCP folder F, then
            user A potentially has access to the GCP folder F. And those
            advanced analysis results will be included in [AnalyzeIamPolic
            yResponse.service_account_impersonation_analysis][google.cloud
            .asset.v1p4beta1.AnalyzeIamPolicyResponse.service_account_impe
            rsonation_analysis].  Default is false.
        execution_timeout:
            Optional. Amount of time executable has to complete. See JSON
            representation of `Duration
            <https://developers.google.com/protocol-
            buffers/docs/proto3#json>`__.  If this field is set with a
            value less than the RPC deadline, and the execution of your
            query hasn’t finished in the specified execution timeout, you
            will get a response with partial result. Otherwise, your
            query’s execution will continue until the RPC deadline. If
            it’s not finished until then, you will get a DEADLINE_EXCEEDED
            error.  Default is empty.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest.Options)
            },
        ),
        "DESCRIPTOR": _ANALYZEIAMPOLICYREQUEST,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """A request message for
  [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1p4beta1.AssetService.AnalyzeIamPolicy].
  
  
  Attributes:
      analysis_query:
          Required. The request query.
      options:
          Optional. The request options.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.AnalyzeIamPolicyRequest)
    },
)
_sym_db.RegisterMessage(AnalyzeIamPolicyRequest)
_sym_db.RegisterMessage(AnalyzeIamPolicyRequest.Options)

AnalyzeIamPolicyResponse = _reflection.GeneratedProtocolMessageType(
    "AnalyzeIamPolicyResponse",
    (_message.Message,),
    {
        "IamPolicyAnalysis": _reflection.GeneratedProtocolMessageType(
            "IamPolicyAnalysis",
            (_message.Message,),
            {
                "DESCRIPTOR": _ANALYZEIAMPOLICYRESPONSE_IAMPOLICYANALYSIS,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """An analysis message to group the query and results.
    
    
    Attributes:
        analysis_query:
            The analysis query.
        analysis_results:
            A list of [IamPolicyAnalysisResult][google.cloud.asset.v1p4bet
            a1.IamPolicyAnalysisResult] that matches the analysis query,
            or empty if no result is found.
        fully_explored:
            Represents whether all entries in the [analysis_results][googl
            e.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnal
            ysis.analysis_results] have been fully explored to answer the
            query.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse.IamPolicyAnalysis)
            },
        ),
        "DESCRIPTOR": _ANALYZEIAMPOLICYRESPONSE,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """A response message for
  [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1p4beta1.AssetService.AnalyzeIamPolicy].
  
  
  Attributes:
      main_analysis:
          The main analysis that matches the original request.
      service_account_impersonation_analysis:
          The service account impersonation analysis if [AnalyzeIamPolic
          yRequest.analyze_service_account_impersonation][] is enabled.
      fully_explored:
          Represents whether all entries in the [main_analysis][google.c
          loud.asset.v1p4beta1.AnalyzeIamPolicyResponse.main_analysis]
          and [service_account_impersonation_analysis][google.cloud.asse
          t.v1p4beta1.AnalyzeIamPolicyResponse.service_account_impersona
          tion_analysis] have been fully explored to answer the query in
          the request.
      non_critical_errors:
          A list of non-critical errors happened during the request
          handling to explain why ``fully_explored`` is false, or empty
          if no error happened.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.AnalyzeIamPolicyResponse)
    },
)
_sym_db.RegisterMessage(AnalyzeIamPolicyResponse)
_sym_db.RegisterMessage(AnalyzeIamPolicyResponse.IamPolicyAnalysis)

IamPolicyAnalysisOutputConfig = _reflection.GeneratedProtocolMessageType(
    "IamPolicyAnalysisOutputConfig",
    (_message.Message,),
    {
        "GcsDestination": _reflection.GeneratedProtocolMessageType(
            "GcsDestination",
            (_message.Message,),
            {
                "DESCRIPTOR": _IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """A Cloud Storage location.
    
    
    Attributes:
        uri:
            Required. The uri of the Cloud Storage object. It’s the same
            uri that is used by gsutil. For example:
            “gs://bucket_name/object_name”. See `Viewing and Editing
            Object Metadata
            <https://cloud.google.com/storage/docs/viewing-editing-
            metadata>`__ for more information.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig.GcsDestination)
            },
        ),
        "DESCRIPTOR": _IAMPOLICYANALYSISOUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """Output configuration for export IAM policy analysis
  destination.
  
  
  Attributes:
      destination:
          IAM policy analysis export destination.
      gcs_destination:
          Destination on Cloud Storage.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.IamPolicyAnalysisOutputConfig)
    },
)
_sym_db.RegisterMessage(IamPolicyAnalysisOutputConfig)
_sym_db.RegisterMessage(IamPolicyAnalysisOutputConfig.GcsDestination)

ExportIamPolicyAnalysisRequest = _reflection.GeneratedProtocolMessageType(
    "ExportIamPolicyAnalysisRequest",
    (_message.Message,),
    {
        "Options": _reflection.GeneratedProtocolMessageType(
            "Options",
            (_message.Message,),
            {
                "DESCRIPTOR": _EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS,
                "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
                "__doc__": """Contains request options.
    
    
    Attributes:
        expand_groups:
            Optional. If true, the identities section of the result will
            expand any Google groups appearing in an IAM policy binding.
            If [identity_selector][] is specified, the identity in the
            result will be determined by the selector, and this flag will
            have no effect.  Default is false.
        expand_roles:
            Optional. If true, the access section of result will expand
            any roles appearing in IAM policy bindings to include their
            permissions.  If [access_selector][] is specified, the access
            section of the result will be determined by the selector, and
            this flag will have no effect.  Default is false.
        expand_resources:
            Optional. If true, the resource section of the result will
            expand any resource attached to an IAM policy to include
            resources lower in the resource hierarchy.  For example, if
            the request analyzes for which resources user A has permission
            P, and the results include an IAM policy with P on a GCP
            folder, the results will also include resources in that folder
            with permission P.  If [resource_selector][] is specified, the
            resource section of the result will be determined by the
            selector, and this flag will have no effect. Default is false.
        output_resource_edges:
            Optional. If true, the result will output resource edges,
            starting from the policy attached resource, to any expanded
            resources. Default is false.
        output_group_edges:
            Optional. If true, the result will output group identity
            edges, starting from the binding’s group members, to any
            expanded identities. Default is false.
        analyze_service_account_impersonation:
            Optional. If true, the response will include access analysis
            from identities to resources via service account
            impersonation. This is a very expensive operation, because
            many derived queries will be executed.  For example, if the
            request analyzes for which resources user A has permission P,
            and there’s an IAM policy states user A has
            iam.serviceAccounts.getAccessToken permission to a service
            account SA, and there’s another IAM policy states service
            account SA has permission P to a GCP folder F, then user A
            potentially has access to the GCP folder F. And those advanced
            analysis results will be included in [AnalyzeIamPolicyResponse
            .service_account_impersonation_analysis][google.cloud.asset.v1
            p4beta1.AnalyzeIamPolicyResponse.service_account_impersonation
            _analysis].  Another example, if the request analyzes for who
            has permission P to a GCP folder F, and there’s an IAM policy
            states user A has iam.serviceAccounts.actAs permission to a
            service account SA, and there’s another IAM policy states
            service account SA has permission P to the GCP folder F, then
            user A potentially has access to the GCP folder F. And those
            advanced analysis results will be included in [AnalyzeIamPolic
            yResponse.service_account_impersonation_analysis][google.cloud
            .asset.v1p4beta1.AnalyzeIamPolicyResponse.service_account_impe
            rsonation_analysis].  Default is false.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest.Options)
            },
        ),
        "DESCRIPTOR": _EXPORTIAMPOLICYANALYSISREQUEST,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """A request message for
  [AssetService.ExportIamPolicyAnalysis][google.cloud.asset.v1p4beta1.AssetService.ExportIamPolicyAnalysis].
  
  
  Attributes:
      analysis_query:
          Required. The request query.
      options:
          Optional. The request options.
      output_config:
          Required. Output configuration indicating where the results
          will be output to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest)
    },
)
_sym_db.RegisterMessage(ExportIamPolicyAnalysisRequest)
_sym_db.RegisterMessage(ExportIamPolicyAnalysisRequest.Options)

ExportIamPolicyAnalysisResponse = _reflection.GeneratedProtocolMessageType(
    "ExportIamPolicyAnalysisResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTIAMPOLICYANALYSISRESPONSE,
        "__module__": "google.cloud.asset_v1p4beta1.proto.asset_service_pb2",
        "__doc__": """The export IAM policy analysis response. This message is
  returned by the [google.longrunning.Operations.GetOperation][] method in
  the returned [google.longrunning.Operation.response][] field.
  
  
  Attributes:
      output_config:
          Output configuration indicating where the results were output
          to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisResponse)
    },
)
_sym_db.RegisterMessage(ExportIamPolicyAnalysisResponse)


DESCRIPTOR._options = None
_IAMPOLICYANALYSISQUERY_RESOURCESELECTOR.fields_by_name[
    "full_resource_name"
]._options = None
_IAMPOLICYANALYSISQUERY_IDENTITYSELECTOR.fields_by_name["identity"]._options = None
_IAMPOLICYANALYSISQUERY_ACCESSSELECTOR.fields_by_name["roles"]._options = None
_IAMPOLICYANALYSISQUERY_ACCESSSELECTOR.fields_by_name["permissions"]._options = None
_IAMPOLICYANALYSISQUERY.fields_by_name["parent"]._options = None
_IAMPOLICYANALYSISQUERY.fields_by_name["resource_selector"]._options = None
_IAMPOLICYANALYSISQUERY.fields_by_name["identity_selector"]._options = None
_IAMPOLICYANALYSISQUERY.fields_by_name["access_selector"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["expand_groups"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["expand_roles"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["expand_resources"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["output_resource_edges"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["output_group_edges"]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name[
    "analyze_service_account_impersonation"
]._options = None
_ANALYZEIAMPOLICYREQUEST_OPTIONS.fields_by_name["execution_timeout"]._options = None
_ANALYZEIAMPOLICYREQUEST.fields_by_name["analysis_query"]._options = None
_ANALYZEIAMPOLICYREQUEST.fields_by_name["options"]._options = None
_IAMPOLICYANALYSISOUTPUTCONFIG_GCSDESTINATION.fields_by_name["uri"]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name["expand_groups"]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name["expand_roles"]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name[
    "expand_resources"
]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name[
    "output_resource_edges"
]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name[
    "output_group_edges"
]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST_OPTIONS.fields_by_name[
    "analyze_service_account_impersonation"
]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name["analysis_query"]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name["options"]._options = None
_EXPORTIAMPOLICYANALYSISREQUEST.fields_by_name["output_config"]._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1p4beta1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=2710,
    serialized_end=3323,
    methods=[
        _descriptor.MethodDescriptor(
            name="AnalyzeIamPolicy",
            full_name="google.cloud.asset.v1p4beta1.AssetService.AnalyzeIamPolicy",
            index=0,
            containing_service=None,
            input_type=_ANALYZEIAMPOLICYREQUEST,
            output_type=_ANALYZEIAMPOLICYRESPONSE,
            serialized_options=b"\202\323\344\223\0029\0227/v1p4beta1/{analysis_query.parent=*/*}:analyzeIamPolicy",
        ),
        _descriptor.MethodDescriptor(
            name="ExportIamPolicyAnalysis",
            full_name="google.cloud.asset.v1p4beta1.AssetService.ExportIamPolicyAnalysis",
            index=1,
            containing_service=None,
            input_type=_EXPORTIAMPOLICYANALYSISREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002C">/v1p4beta1/{analysis_query.parent=*/*}:exportIamPolicyAnalysis:\001*\312A{\n<google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisResponse\022;google.cloud.asset.v1p4beta1.ExportIamPolicyAnalysisRequest',
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)
